@@ -23,17 +23,11 @@ require(rJava, quietly=TRUE)
         Sys.setenv("DYLD_LIBRARY_PATH"=sub("/usr/X11R6/lib","",dlp))
     }
 
-    .jinit(classpath=c(
-        paste(lib,pkg,"java","arq-2.8.7.jar",sep=.Platform$file.sep),
-        paste(lib,pkg,"java","icu4j-3.4.4.jar",sep=.Platform$file.sep),
-        paste(lib,pkg,"java","iri-0.8.jar",sep=.Platform$file.sep),
-        paste(lib,pkg,"java","jena-2.6.4.jar",sep=.Platform$file.sep),
-        paste(lib,pkg,"java","log4j-1.2.13.jar",sep=.Platform$file.sep),
-        paste(lib,pkg,"java","lucene-core-2.3.1.jar",sep=.Platform$file.sep),
-        paste(lib,pkg,"java","slf4j-api-1.5.8.jar",sep=.Platform$file.sep),
-        paste(lib,pkg,"java","slf4j-log4j12-1.5.8.jar",sep=.Platform$file.sep),
-        paste(lib,pkg,"java","stax-api-1.0.1.jar",sep=.Platform$file.sep),
-        paste(lib,pkg,"java","wstx-asl-3.2.9.jar",sep=.Platform$file.sep),
-        paste(lib,pkg,"java","xercesImpl-2.7.1.jar",sep=.Platform$file.sep)
-    ))
+	jenaJars = c(
+		"arq-2.8.7.jar", "icu4j-3.4.4.jar", "iri-0.8.jar",
+		"jena-2.6.4.jar", "log4j-1.2.13.jar", "lucene-core-2.3.1.jar",
+		"slf4j-api-1.5.8.jar", "slf4j-log4j12-1.5.8.jar",
+		"wstx-asl-3.2.9.jar", "xercesImpl-2.7.1.jar"
+	)
+	.jpackage(pkg, jars=jenaJars)
 }
